Index: src/mips/macro-assembler-mips.h |
diff --git a/src/mips/macro-assembler-mips.h b/src/mips/macro-assembler-mips.h |
index ffae2fd69e06aa9665cc4bd2be84607bf3188652..bc3e7c48b4a5bd922d455352b294e584c5a98ee6 100644 |
--- a/src/mips/macro-assembler-mips.h |
+++ b/src/mips/macro-assembler-mips.h |
@@ -1460,16 +1460,16 @@ class MacroAssembler: public Assembler { |
// in a0. Assumes that any other register can be used as a scratch. |
void CheckEnumCache(Register null_value, Label* call_runtime); |
// AllocationSiteInfo support. Arrays may have an associated |
// AllocationSiteInfo object that can be checked for in order to pretransition |
// to another type. |
// On entry, receiver_reg should point to the array object. |
// scratch_reg gets clobbered. |
// If allocation info is present, jump to allocation_info_present |
- void TestJSArrayForAllocationSiteInfo(Register receiver_reg, |
- Register scratch_reg, |
- Condition cond, |
- Label* allocation_info_present); |
+ void TestJSArrayForAllocationMemento(Register receiver_reg, |
+ Register scratch_reg, |
+ Condition cond, |
+ Label* allocation_memento_present); |
private: |
void CallCFunctionHelper(Register function, |
@@ -1460,16 +1460,16 @@ class MacroAssembler: public Assembler { |
// in a0. Assumes that any other register can be used as a scratch. |
void CheckEnumCache(Register null_value, Label* call_runtime); |
- // AllocationSiteInfo support. Arrays may have an associated |
- // AllocationSiteInfo object that can be checked for in order to pretransition |
+ // AllocationMemento support. Arrays may have an associated |
+ // AllocationMemento object that can be checked for in order to pretransition |
// to another type. |
// On entry, receiver_reg should point to the array object. |